Crate icu_relativetime_data

Crate icu_relativetime_data 

Data for the icu_relativetime crate

Macros

impl_relativetime_long_day_v1
Implement DataProvider<LongDayRelativeTimeFormatDataV1Marker> on the given struct using the data hardcoded in this file. This allows the struct to be used with icu’s _unstable constructors.
impl_relativetime_long_hour_v1
Implement DataProvider<LongHourRelativeTimeFormatDataV1Marker> on the given struct using the data hardcoded in this file. This allows the struct to be used with icu’s _unstable constructors.
impl_relativetime_long_minute_v1
Implement DataProvider<LongMinuteRelativeTimeFormatDataV1Marker> on the given struct using the data hardcoded in this file. This allows the struct to be used with icu’s _unstable constructors.
impl_relativetime_long_month_v1
Implement DataProvider<LongMonthRelativeTimeFormatDataV1Marker> on the given struct using the data hardcoded in this file. This allows the struct to be used with icu’s _unstable constructors.
impl_relativetime_long_quarter_v1
Implement DataProvider<LongQuarterRelativeTimeFormatDataV1Marker> on the given struct using the data hardcoded in this file. This allows the struct to be used with icu’s _unstable constructors.
impl_relativetime_long_second_v1
Implement DataProvider<LongSecondRelativeTimeFormatDataV1Marker> on the given struct using the data hardcoded in this file. This allows the struct to be used with icu’s _unstable constructors.
impl_relativetime_long_week_v1
Implement DataProvider<LongWeekRelativeTimeFormatDataV1Marker> on the given struct using the data hardcoded in this file. This allows the struct to be used with icu’s _unstable constructors.
impl_relativetime_long_year_v1
Implement DataProvider<LongYearRelativeTimeFormatDataV1Marker> on the given struct using the data hardcoded in this file. This allows the struct to be used with icu’s _unstable constructors.
impl_relativetime_narrow_day_v1
Implement DataProvider<NarrowDayRelativeTimeFormatDataV1Marker> on the given struct using the data hardcoded in this file. This allows the struct to be used with icu’s _unstable constructors.
impl_relativetime_narrow_hour_v1
Implement DataProvider<NarrowHourRelativeTimeFormatDataV1Marker> on the given struct using the data hardcoded in this file. This allows the struct to be used with icu’s _unstable constructors.
impl_relativetime_narrow_minute_v1
Implement DataProvider<NarrowMinuteRelativeTimeFormatDataV1Marker> on the given struct using the data hardcoded in this file. This allows the struct to be used with icu’s _unstable constructors.
impl_relativetime_narrow_month_v1
Implement DataProvider<NarrowMonthRelativeTimeFormatDataV1Marker> on the given struct using the data hardcoded in this file. This allows the struct to be used with icu’s _unstable constructors.
impl_relativetime_narrow_quarter_v1
Implement DataProvider<NarrowQuarterRelativeTimeFormatDataV1Marker> on the given struct using the data hardcoded in this file. This allows the struct to be used with icu’s _unstable constructors.
impl_relativetime_narrow_second_v1
Implement DataProvider<NarrowSecondRelativeTimeFormatDataV1Marker> on the given struct using the data hardcoded in this file. This allows the struct to be used with icu’s _unstable constructors.
impl_relativetime_narrow_week_v1
Implement DataProvider<NarrowWeekRelativeTimeFormatDataV1Marker> on the given struct using the data hardcoded in this file. This allows the struct to be used with icu’s _unstable constructors.
impl_relativetime_narrow_year_v1
Implement DataProvider<NarrowYearRelativeTimeFormatDataV1Marker> on the given struct using the data hardcoded in this file. This allows the struct to be used with icu’s _unstable constructors.
impl_relativetime_short_day_v1
Implement DataProvider<ShortDayRelativeTimeFormatDataV1Marker> on the given struct using the data hardcoded in this file. This allows the struct to be used with icu’s _unstable constructors.
impl_relativetime_short_hour_v1
Implement DataProvider<ShortHourRelativeTimeFormatDataV1Marker> on the given struct using the data hardcoded in this file. This allows the struct to be used with icu’s _unstable constructors.
impl_relativetime_short_minute_v1
Implement DataProvider<ShortMinuteRelativeTimeFormatDataV1Marker> on the given struct using the data hardcoded in this file. This allows the struct to be used with icu’s _unstable constructors.
impl_relativetime_short_month_v1
Implement DataProvider<ShortMonthRelativeTimeFormatDataV1Marker> on the given struct using the data hardcoded in this file. This allows the struct to be used with icu’s _unstable constructors.
impl_relativetime_short_quarter_v1
Implement DataProvider<ShortQuarterRelativeTimeFormatDataV1Marker> on the given struct using the data hardcoded in this file. This allows the struct to be used with icu’s _unstable constructors.
impl_relativetime_short_second_v1
Implement DataProvider<ShortSecondRelativeTimeFormatDataV1Marker> on the given struct using the data hardcoded in this file. This allows the struct to be used with icu’s _unstable constructors.
impl_relativetime_short_week_v1
Implement DataProvider<ShortWeekRelativeTimeFormatDataV1Marker> on the given struct using the data hardcoded in this file. This allows the struct to be used with icu’s _unstable constructors.
impl_relativetime_short_year_v1
Implement DataProvider<ShortYearRelativeTimeFormatDataV1Marker> on the given struct using the data hardcoded in this file. This allows the struct to be used with icu’s _unstable constructors.
make_provider
Marks a type as a data provider. You can then use macros like impl_core_helloworld_v1 to add implementations.