Data for the icu_relativetime crate
Macros
- impl_
relativetime_ long_ day_ v1 - Implement
DataProvider<LongDayRelativeTimeFormatDataV1Marker>on the given struct using the data hardcoded in this file. This allows the struct to be used withicu’s_unstableconstructors. - impl_
relativetime_ long_ hour_ v1 - Implement
DataProvider<LongHourRelativeTimeFormatDataV1Marker>on the given struct using the data hardcoded in this file. This allows the struct to be used withicu’s_unstableconstructors. - impl_
relativetime_ long_ minute_ v1 - Implement
DataProvider<LongMinuteRelativeTimeFormatDataV1Marker>on the given struct using the data hardcoded in this file. This allows the struct to be used withicu’s_unstableconstructors. - impl_
relativetime_ long_ month_ v1 - Implement
DataProvider<LongMonthRelativeTimeFormatDataV1Marker>on the given struct using the data hardcoded in this file. This allows the struct to be used withicu’s_unstableconstructors. - impl_
relativetime_ long_ quarter_ v1 - Implement
DataProvider<LongQuarterRelativeTimeFormatDataV1Marker>on the given struct using the data hardcoded in this file. This allows the struct to be used withicu’s_unstableconstructors. - impl_
relativetime_ long_ second_ v1 - Implement
DataProvider<LongSecondRelativeTimeFormatDataV1Marker>on the given struct using the data hardcoded in this file. This allows the struct to be used withicu’s_unstableconstructors. - impl_
relativetime_ long_ week_ v1 - Implement
DataProvider<LongWeekRelativeTimeFormatDataV1Marker>on the given struct using the data hardcoded in this file. This allows the struct to be used withicu’s_unstableconstructors. - impl_
relativetime_ long_ year_ v1 - Implement
DataProvider<LongYearRelativeTimeFormatDataV1Marker>on the given struct using the data hardcoded in this file. This allows the struct to be used withicu’s_unstableconstructors. - impl_
relativetime_ narrow_ day_ v1 - Implement
DataProvider<NarrowDayRelativeTimeFormatDataV1Marker>on the given struct using the data hardcoded in this file. This allows the struct to be used withicu’s_unstableconstructors. - impl_
relativetime_ narrow_ hour_ v1 - Implement
DataProvider<NarrowHourRelativeTimeFormatDataV1Marker>on the given struct using the data hardcoded in this file. This allows the struct to be used withicu’s_unstableconstructors. - impl_
relativetime_ narrow_ minute_ v1 - Implement
DataProvider<NarrowMinuteRelativeTimeFormatDataV1Marker>on the given struct using the data hardcoded in this file. This allows the struct to be used withicu’s_unstableconstructors. - impl_
relativetime_ narrow_ month_ v1 - Implement
DataProvider<NarrowMonthRelativeTimeFormatDataV1Marker>on the given struct using the data hardcoded in this file. This allows the struct to be used withicu’s_unstableconstructors. - impl_
relativetime_ narrow_ quarter_ v1 - Implement
DataProvider<NarrowQuarterRelativeTimeFormatDataV1Marker>on the given struct using the data hardcoded in this file. This allows the struct to be used withicu’s_unstableconstructors. - impl_
relativetime_ narrow_ second_ v1 - Implement
DataProvider<NarrowSecondRelativeTimeFormatDataV1Marker>on the given struct using the data hardcoded in this file. This allows the struct to be used withicu’s_unstableconstructors. - impl_
relativetime_ narrow_ week_ v1 - Implement
DataProvider<NarrowWeekRelativeTimeFormatDataV1Marker>on the given struct using the data hardcoded in this file. This allows the struct to be used withicu’s_unstableconstructors. - impl_
relativetime_ narrow_ year_ v1 - Implement
DataProvider<NarrowYearRelativeTimeFormatDataV1Marker>on the given struct using the data hardcoded in this file. This allows the struct to be used withicu’s_unstableconstructors. - impl_
relativetime_ short_ day_ v1 - Implement
DataProvider<ShortDayRelativeTimeFormatDataV1Marker>on the given struct using the data hardcoded in this file. This allows the struct to be used withicu’s_unstableconstructors. - impl_
relativetime_ short_ hour_ v1 - Implement
DataProvider<ShortHourRelativeTimeFormatDataV1Marker>on the given struct using the data hardcoded in this file. This allows the struct to be used withicu’s_unstableconstructors. - impl_
relativetime_ short_ minute_ v1 - Implement
DataProvider<ShortMinuteRelativeTimeFormatDataV1Marker>on the given struct using the data hardcoded in this file. This allows the struct to be used withicu’s_unstableconstructors. - impl_
relativetime_ short_ month_ v1 - Implement
DataProvider<ShortMonthRelativeTimeFormatDataV1Marker>on the given struct using the data hardcoded in this file. This allows the struct to be used withicu’s_unstableconstructors. - impl_
relativetime_ short_ quarter_ v1 - Implement
DataProvider<ShortQuarterRelativeTimeFormatDataV1Marker>on the given struct using the data hardcoded in this file. This allows the struct to be used withicu’s_unstableconstructors. - impl_
relativetime_ short_ second_ v1 - Implement
DataProvider<ShortSecondRelativeTimeFormatDataV1Marker>on the given struct using the data hardcoded in this file. This allows the struct to be used withicu’s_unstableconstructors. - impl_
relativetime_ short_ week_ v1 - Implement
DataProvider<ShortWeekRelativeTimeFormatDataV1Marker>on the given struct using the data hardcoded in this file. This allows the struct to be used withicu’s_unstableconstructors. - impl_
relativetime_ short_ year_ v1 - Implement
DataProvider<ShortYearRelativeTimeFormatDataV1Marker>on the given struct using the data hardcoded in this file. This allows the struct to be used withicu’s_unstableconstructors. - make_
provider - Marks a type as a data provider. You can then use macros like
impl_core_helloworld_v1to add implementations.